# src/better_anonymity/__init__.py
import os
import subprocess
import sys
from pathlib import Path

def main():
    # The script is stored inside the package under bin/
    entry = Path(__file__).resolve().parent / "bin" / "better-anonymity"
    # If we are running from a source checkout (no installed bin script),
    # fall back to the repository root.
    if not entry.is_file():
        repo_root = Path(__file__).resolve().parents[2]
        entry = repo_root / "bin" / "better-anonymity"
    sys.exit(subprocess.call([str(entry)] + sys.argv[1:]))


if __name__ == "__main__":
    main()
__version__ = "1.0.4"



# setup.py
from setuptools import setup

from setuptools.command.build_py import build_py
import os
import shutil

class CustomBuildPy(build_py):
    def run(self):
        super().run()
        # The python package is built into self.build_lib
        pkg_dir = os.path.join(self.build_lib, 'better_anonymity')
        # Copy the bash script assets into the built package
        for d in ['bin', 'lib', 'config']:
            dest = os.path.join(pkg_dir, d)
            if os.path.exists(d):
                shutil.copytree(d, dest, dirs_exist_ok=True)

if __name__ == "__main__":
    setup(cmdclass={'build_py': CustomBuildPy})
